@@ -16,6 +16,7 @@
 //
 
 #include "legacy_compat.hpp"
+#include "../usrp/device3/device3_impl.hpp"
 #include <uhd/property_tree.hpp>
 #include <uhd/rfnoc/radio_ctrl.hpp>
 #include <uhd/rfnoc/ddc_block_ctrl.hpp>
@@ -38,7 +39,7 @@ using uhd::usrp::subdev_spec_pair_t;
 using uhd::stream_cmd_t;
 
 /************************************************************************
- * Constants
+ * Constants and globals
  ***********************************************************************/
 static const std::string RADIO_BLOCK_NAME = "Radio";
 static const std::string DFIFO_BLOCK_NAME = "DmaFIFO";
@@ -47,6 +48,7 @@ static const std::string DUC_BLOCK_NAME = "DUC";
 static const size_t MAX_BYTES_PER_HEADER =
         uhd::transport::vrt::chdr::max_if_hdr_words64 * sizeof(uint64_t);
 static const size_t BYTES_PER_SAMPLE = 4; // We currently only support sc16
+static boost::mutex _make_mutex;
 
 /************************************************************************
  * Static helpers
@@ -170,6 +172,13 @@ public:
     /************************************************************************
      * API Calls
      ***********************************************************************/
+    inline uhd::fs_path rx_dsp_root(const size_t mboard_idx, const size_t dsp_index, const size_t port_index)
+    {
+        return mb_root(mboard_idx) / "xbar" /
+               str(boost::format("%s_%d") % DDC_BLOCK_NAME % dsp_index) /
+               "legacy_api" / port_index;
+    }
+
     uhd::fs_path rx_dsp_root(const size_t mboard_idx, const size_t chan)
     {
         // The DSP index is the same as the radio index
@@ -180,8 +189,13 @@ public:
             return mb_root(mboard_idx) / "rx_dsps" / dsp_index / port_index;
         }
 
+        return rx_dsp_root(mboard_idx, dsp_index, port_index);
+    }
+
+    inline uhd::fs_path tx_dsp_root(const size_t mboard_idx, const size_t dsp_index, const size_t port_index)
+    {
         return mb_root(mboard_idx) / "xbar" /
-               str(boost::format("%s_%d") % DDC_BLOCK_NAME % dsp_index) /
+               str(boost::format("%s_%d") % DUC_BLOCK_NAME % dsp_index) /
                "legacy_api" / port_index;
     }
 
@@ -195,9 +209,7 @@ public:
             return mb_root(mboard_idx) / "tx_dsps" / dsp_index / port_index;
         }
 
-        return mb_root(mboard_idx) / "xbar" /
-               str(boost::format("%s_%d") % DUC_BLOCK_NAME % dsp_index) /
-               "legacy_api" / port_index;
+        return tx_dsp_root(mboard_idx, dsp_index, port_index);
     }
 
     uhd::fs_path rx_fe_root(const size_t mboard_idx, const size_t chan)
@@ -510,6 +522,20 @@ private: // methods
                         ;
                     }
                 }
+            } else {
+                for (size_t dsp_idx = 0; dsp_idx < _num_radios_per_board; dsp_idx++) {
+                    for (size_t chan = 0; chan < _num_rx_chans_per_radio; chan++) {
+                        _tree->access<double>(rx_dsp_root(mboard_idx, dsp_idx, chan) / "rate/value")
+                            .add_coerced_subscriber(
+                                boost::bind(
+                                    &uhd::usrp::device3_impl::update_rx_streamers,
+                                    boost::dynamic_pointer_cast<uhd::usrp::device3_impl>(_device),
+                                    _1
+                                )
+                            )
+                        ;
+                    }
+                }
             }
             if (not _has_ducs) {
                 for (size_t radio_idx = 0; radio_idx < _num_radios_per_board; radio_idx++) {
@@ -543,7 +569,21 @@ private: // methods
                         ;
                     }
                 }
-            }
+            } else {
+                for (size_t dsp_idx = 0; dsp_idx < _num_radios_per_board; dsp_idx++) {
+                    for (size_t chan = 0; chan < _num_tx_chans_per_radio; chan++) {
+                        _tree->access<double>(tx_dsp_root(mboard_idx, dsp_idx, chan) / "rate/value")
+                            .add_coerced_subscriber(
+                                boost::bind(
+                                    &uhd::usrp::device3_impl::update_tx_streamers,
+                                    boost::dynamic_pointer_cast<uhd::usrp::device3_impl>(_device),
+                                    _1
+                                )
+                            )
+                        ;
+                    }
+                }
+            } /* if not _has_ducs */
         }
     }
 
@@ -700,15 +740,13 @@ legacy_compat::sptr legacy_compat::make(
         uhd::device3::sptr device,
         const uhd::device_addr_t &args
 ) {
+    boost::lock_guard<boost::mutex> lock(_make_mutex);
     UHD_ASSERT_THROW(bool(device));
     static std::map<void *, boost::weak_ptr<legacy_compat> > legacy_cache;
 
-    if (legacy_cache.count(device.get())) {
+    if (legacy_cache.count(device.get()) and not legacy_cache.at(device.get()).expired()) {
         legacy_compat::sptr legacy_compat_copy = legacy_cache.at(device.get()).lock();
-        if (not bool(legacy_compat_copy)) {
-            throw uhd::runtime_error("Reference to existing legacy compat object expired prematurely!");
-        }
-
+        UHD_ASSERT_THROW(bool(legacy_compat_copy));
         UHD_LEGACY_LOG() << "[legacy_compat] Using existing legacy compat object for this device." << std::endl;
         return legacy_compat_copy;
     }
