@@ -18,6 +18,7 @@
 #ifndef INCLUDED_LIBUHD_TRANSPORT_SUPER_SEND_PACKET_HANDLER_HPP
 #define INCLUDED_LIBUHD_TRANSPORT_SUPER_SEND_PACKET_HANDLER_HPP
 
+#include "../rfnoc/tx_stream_terminator.hpp"
 #include <uhd/config.hpp>
 #include <uhd/exception.hpp>
 #include <uhd/convert.hpp>
@@ -28,9 +29,6 @@
 #include <uhd/types/metadata.hpp>
 #include <uhd/transport/vrt_if_packet.hpp>
 #include <uhd/transport/zero_copy.hpp>
-#ifdef DEVICE3_STREAMER
-#  include "../rfnoc/tx_stream_terminator.hpp"
-#endif
 #include <boost/thread/thread.hpp>
 #include <boost/thread/thread_time.hpp>
 #include <boost/foreach.hpp>
@@ -115,7 +113,6 @@ public:
         }
     }
 
-    #ifdef DEVICE3_STREAMER
     void set_terminator(uhd::rfnoc::tx_stream_terminator::sptr terminator)
     {
         _terminator = terminator;
@@ -125,7 +122,6 @@ public:
     {
         return _terminator;
     }
-    #endif
     ///////// RFNOC ///////////////////
 
     void set_enable_trailer(const bool enable)
@@ -322,9 +318,7 @@ private:
     bool _cached_metadata;
     uhd::tx_metadata_t _metadata_cache;
 
-    #ifdef DEVICE3_STREAMER
     uhd::rfnoc::tx_stream_terminator::sptr _terminator;
-    #endif
 
 #ifdef UHD_TXRX_DEBUG_PRINTS
     struct dbg_send_stat_t {
