@@ -626,10 +626,12 @@ void x300_impl::setup_mb(const size_t mb_i, const uhd::device_addr_t &dev_addr)
         }
 
         if ((mb.recv_args.has_key("recv_frame_size"))
-                && (req_max_frame_size.recv_frame_size < _max_frame_sizes.recv_frame_size)) {
+                && (req_max_frame_size.recv_frame_size > _max_frame_sizes.recv_frame_size)) {
             UHD_MSG(warning)
                 << boost::format("You requested a receive frame size of (%lu) but your NIC's max frame size is (%lu).")
-                % req_max_frame_size.recv_frame_size << _max_frame_sizes.recv_frame_size << std::endl
+                % req_max_frame_size.recv_frame_size
+                % _max_frame_sizes.recv_frame_size
+                << std::endl
                 << boost::format("Please verify your NIC's MTU setting using '%s' or set the recv_frame_size argument appropriately.")
                 % mtu_tool << std::endl
                 << "UHD will use the auto-detected max frame size for this connection."
@@ -637,10 +639,12 @@ void x300_impl::setup_mb(const size_t mb_i, const uhd::device_addr_t &dev_addr)
         }
 
         if ((mb.recv_args.has_key("send_frame_size"))
-                && (req_max_frame_size.send_frame_size < _max_frame_sizes.send_frame_size)) {
+                && (req_max_frame_size.send_frame_size > _max_frame_sizes.send_frame_size)) {
             UHD_MSG(warning)
                 << boost::format("You requested a send frame size of (%lu) but your NIC's max frame size is (%lu).")
-                % req_max_frame_size.send_frame_size << _max_frame_sizes.send_frame_size << std::endl
+                % req_max_frame_size.send_frame_size
+                % _max_frame_sizes.send_frame_size
+                << std::endl
                 << boost::format("Please verify your NIC's MTU setting using '%s' or set the send_frame_size argument appropriately.")
                 % mtu_tool << std::endl
                 << "UHD will use the auto-detected max frame size for this connection."
@@ -694,7 +698,7 @@ void x300_impl::setup_mb(const size_t mb_i, const uhd::device_addr_t &dev_addr)
     mb.zpu_spi = spi_core_3000::make(mb.zpu_ctrl, SR_ADDR(SET0_BASE, ZPU_SR_SPI),
             SR_ADDR(SET0_BASE, ZPU_RB_SPI));
     mb.zpu_i2c = i2c_core_100_wb32::make(mb.zpu_ctrl, I2C1_BASE);
-    mb.zpu_i2c->set_clock_rate(X300_BUS_CLOCK_RATE);
+    mb.zpu_i2c->set_clock_rate(X300_BUS_CLOCK_RATE/2);
 
     ////////////////////////////////////////////////////////////////////
     // print network routes mapping
@@ -956,7 +960,12 @@ void x300_impl::setup_mb(const size_t mb_i, const uhd::device_addr_t &dev_addr)
         BOOST_FOREACH(const rfnoc::block_id_t &id, radio_ids) {
             rfnoc::x300_radio_ctrl_impl::sptr radio(get_block_ctrl<rfnoc::x300_radio_ctrl_impl>(id));
             mb.radios.push_back(radio);
-            radio->setup_radio(mb.zpu_i2c, mb.clock, dev_addr.has_key("self_cal_adc_delay"));
+            radio->setup_radio(
+                    mb.zpu_i2c,
+                    mb.clock,
+                    dev_addr.has_key("ignore-cal-file"),
+                    dev_addr.has_key("self_cal_adc_delay")
+            );
         }
 
         ////////////////////////////////////////////////////////////////////
@@ -977,9 +986,17 @@ void x300_impl::setup_mb(const size_t mb_i, const uhd::device_addr_t &dev_addr)
                 mb.radios.at(i)->self_test_adc();
             }
         }
+
+        ////////////////////////////////////////////////////////////////////
+        // Synchronize times (dboard initialization can desynchronize them)
+        ////////////////////////////////////////////////////////////////////
+        if (radio_ids.size() == 2) {
+            this->sync_times(mb, mb.radios[0]->get_time_now());
+        }
+
     } else {
         UHD_MSG(status) << "No Radio Block found. Assuming radio-less operation." << std::endl;
-    }
+    } /* end of radio block(s) initialization */
 
     mb.initialization_done = true;
 }
@@ -1020,7 +1037,7 @@ uint32_t x300_impl::allocate_pcie_dma_chan(const uhd::sid_t &tx_sid, const xport
 
         if (_dma_chan_pool.count(raw_sid) == 0) {
             _dma_chan_pool[raw_sid] = _dma_chan_pool.size() + FIRST_DATA_CHANNEL;
-            UHD_MSG(status) << "[X300] Assigning PCIe DMA channel " << _dma_chan_pool[raw_sid]
+            UHD_LOG << "[X300] Assigning PCIe DMA channel " << _dma_chan_pool[raw_sid]
                             << " to SID " << tx_sid.to_pp_string_hex() << std::endl;
         }
 
@@ -1436,11 +1453,6 @@ bool x300_impl::is_pps_present(mboard_members_t& mb)
  * eeprom
  **********************************************************************/
 
-void x300_impl::set_db_eeprom(i2c_iface::sptr i2c, const size_t addr, const uhd::usrp::dboard_eeprom_t &db_eeprom)
-{
-    db_eeprom.store(*i2c, addr);
-}
-
 void x300_impl::set_mb_eeprom(i2c_iface::sptr i2c, const mboard_eeprom_t &mb_eeprom)
 {
     i2c_iface::sptr eeprom16 = i2c->eeprom16();
@@ -1494,10 +1506,11 @@ x300_impl::frame_size_t x300_impl::determine_max_frame_size(const std::string &a
     if (!(uhd::ntohx<boost::uint32_t>(request->flags) & X300_MTU_DETECT_ECHO_REPLY))
         throw uhd::not_implemented_error("Holler protocol not implemented");
 
+    //Reducing range of (min,max) by setting max value to 10gig max_frame_size as larger sizes are not supported
     size_t min_recv_frame_size = sizeof(x300_mtu_t);
-    size_t max_recv_frame_size = user_frame_size.recv_frame_size;
+    size_t max_recv_frame_size = std::min(user_frame_size.recv_frame_size, X300_10GE_DATA_FRAME_MAX_SIZE) & size_t(~3);
     size_t min_send_frame_size = sizeof(x300_mtu_t);
-    size_t max_send_frame_size = user_frame_size.send_frame_size;
+    size_t max_send_frame_size = std::min(user_frame_size.send_frame_size, X300_10GE_DATA_FRAME_MAX_SIZE) & size_t(~3);
 
     UHD_MSG(status) << "Determining maximum frame size... ";
     while (min_recv_frame_size < max_recv_frame_size)
@@ -1659,6 +1672,7 @@ x300_impl::x300_mboard_t x300_impl::get_mb_type_from_pcie(const std::string& res
                 case X310_2943R_40MHz_PCIE_SSID_ADC_18:
                 case X310_2943R_120MHz_PCIE_SSID_ADC_18:
                 case X310_2944R_40MHz_PCIE_SSID_ADC_18:
+                case X310_2945R_PCIE_SSID_ADC_18:
                 case X310_2950R_40MHz_PCIE_SSID_ADC_18:
                 case X310_2950R_120MHz_PCIE_SSID_ADC_18:
                 case X310_2952R_40MHz_PCIE_SSID_ADC_18:
@@ -1666,6 +1680,7 @@ x300_impl::x300_mboard_t x300_impl::get_mb_type_from_pcie(const std::string& res
                 case X310_2953R_40MHz_PCIE_SSID_ADC_18:
                 case X310_2953R_120MHz_PCIE_SSID_ADC_18:
                 case X310_2954R_40MHz_PCIE_SSID_ADC_18:
+                case X310_2955R_PCIE_SSID_ADC_18:
                     mb_type = USRP_X310_MB; break;
                 default:
                     mb_type = UNKNOWN;      break;
@@ -1716,6 +1731,7 @@ x300_impl::x300_mboard_t x300_impl::get_mb_type_from_eeprom(const uhd::usrp::mbo
             case X310_2943R_40MHz_PCIE_SSID_ADC_18:
             case X310_2943R_120MHz_PCIE_SSID_ADC_18:
             case X310_2944R_40MHz_PCIE_SSID_ADC_18:
+            case X310_2945R_PCIE_SSID_ADC_18:
             case X310_2950R_40MHz_PCIE_SSID_ADC_18:
             case X310_2950R_120MHz_PCIE_SSID_ADC_18:
             case X310_2952R_40MHz_PCIE_SSID_ADC_18:
@@ -1723,6 +1739,7 @@ x300_impl::x300_mboard_t x300_impl::get_mb_type_from_eeprom(const uhd::usrp::mbo
             case X310_2953R_40MHz_PCIE_SSID_ADC_18:
             case X310_2953R_120MHz_PCIE_SSID_ADC_18:
             case X310_2954R_40MHz_PCIE_SSID_ADC_18:
+            case X310_2955R_PCIE_SSID_ADC_18:
                 mb_type = USRP_X310_MB; break;
             default:
                 UHD_MSG(warning) << "X300 unknown product code in EEPROM: " << product_num << std::endl;
