@@ -76,8 +76,6 @@ UHD_RFNOC_RADIO_BLOCK_CONSTRUCTOR(x300_radio_ctrl)
     _spi = spi_core_3000::make(ctrl,
         radio_ctrl_impl::regs::sr_addr(radio_ctrl_impl::regs::SPI),
         radio_ctrl_impl::regs::RB_SPI);
-    _leds = gpio_atr::gpio_atr_3000::make_write_only(ctrl, regs::sr_addr(regs::LEDS));
-    _leds->set_atr_mode(usrp::gpio_atr::MODE_ATR, usrp::gpio_atr::gpio_atr_3000::MASK_SET_ALL);
     _adc = x300_adc_ctrl::make(_spi, DB_ADC_SEN);
     _dac = x300_dac_ctrl::make(_spi, DB_DAC_SEN, _radio_clk_rate);
 
@@ -109,7 +107,10 @@ UHD_RFNOC_RADIO_BLOCK_CONSTRUCTOR(x300_radio_ctrl)
     // create front-end objects
     ////////////////////////////////////////////////////////////////
     for (size_t i = 0; i < _get_num_radios(); i++) {
-        _rx_fe_map[i].core = rx_frontend_core_3000::make(_get_ctrl(i), regs::sr_addr(x300_regs::RX_RE_BASE));
+        _leds[i] = gpio_atr::gpio_atr_3000::make_write_only(_get_ctrl(i), regs::sr_addr(regs::LEDS));
+        _leds[i]->set_atr_mode(usrp::gpio_atr::MODE_ATR, usrp::gpio_atr::gpio_atr_3000::MASK_SET_ALL);
+
+        _rx_fe_map[i].core = rx_frontend_core_3000::make(_get_ctrl(i), regs::sr_addr(x300_regs::RX_FE_BASE));
         _rx_fe_map[i].core->set_adc_rate(_radio_clk_rate);
         _rx_fe_map[i].core->set_dc_offset(rx_frontend_core_3000::DEFAULT_DC_OFFSET_VALUE);
         _rx_fe_map[i].core->set_dc_offset_auto(rx_frontend_core_3000::DEFAULT_DC_OFFSET_ENABLE);
@@ -119,6 +120,15 @@ UHD_RFNOC_RADIO_BLOCK_CONSTRUCTOR(x300_radio_ctrl)
         _tx_fe_map[i].core->set_dc_offset(tx_frontend_core_200::DEFAULT_DC_OFFSET_VALUE);
         _tx_fe_map[i].core->set_iq_balance(tx_frontend_core_200::DEFAULT_IQ_BALANCE_VALUE);
         _tx_fe_map[i].core->populate_subtree(_tree->subtree(_root_path / "tx_fe_corrections" / i));
+
+        ////////////////////////////////////////////////////////////////
+        // Bind the daughterboard command time to the motherboard level property
+        ////////////////////////////////////////////////////////////////
+
+        if (_tree->exists(fs_path("time") / "cmd")) {
+            _tree->access<time_spec_t>(fs_path("time") / "cmd")
+                    .add_coerced_subscriber(boost::bind(&x300_radio_ctrl_impl::set_fe_cmd_time, this, _1, i));
+        }
     }
 
     ////////////////////////////////////////////////////////////////
@@ -162,6 +172,13 @@ double x300_radio_ctrl_impl::set_rate(double /* rate */)
     return get_rate();
 }
 
+time_spec_t x300_radio_ctrl_impl::set_fe_cmd_time(const time_spec_t &time, const size_t chan)
+{
+    return _tree->access<time_spec_t>(
+            fs_path("dboards" / _radio_slot /  "rx_frontends" / _rx_fe_map.at(chan).db_fe_name / "time" / "cmd")
+    ).set(time).get();
+}
+
 void x300_radio_ctrl_impl::set_tx_antenna(const std::string &ant, const size_t chan)
 {
     _tree->access<std::string>(
@@ -297,9 +314,14 @@ double x300_radio_ctrl_impl::get_output_samp_rate(size_t chan)
 /****************************************************************************
  * Radio control and setup
  ***************************************************************************/
-void x300_radio_ctrl_impl::setup_radio(uhd::i2c_iface::sptr zpu_i2c, x300_clock_ctrl::sptr clock, bool verbose)
+void x300_radio_ctrl_impl::setup_radio(
+        uhd::i2c_iface::sptr zpu_i2c,
+        x300_clock_ctrl::sptr clock,
+        bool ignore_cal_file,
+        bool verbose)
 {
     _self_cal_adc_capture_delay(verbose);
+    _ignore_cal_file = ignore_cal_file;
 
     ////////////////////////////////////////////////////////////////////
     // create RF frontend interfacing
@@ -322,8 +344,8 @@ void x300_radio_ctrl_impl::setup_radio(uhd::i2c_iface::sptr zpu_i2c, x300_clock_
         //Add to tree
         _tree->create<dboard_eeprom_t>(db_path / EEPROM_PATHS[i])
             .set(_db_eeproms[addr])
-            .add_coerced_subscriber(boost::bind(&dboard_eeprom_t::store,
-                _db_eeproms[addr], boost::ref(*zpu_i2c), (BASE_ADDR | addr)));
+            .add_coerced_subscriber(boost::bind(&x300_radio_ctrl_impl::_set_db_eeprom,
+                this, zpu_i2c, (BASE_ADDR | addr), _1));
     }
 
     //create a new dboard interface
@@ -380,23 +402,38 @@ void x300_radio_ctrl_impl::setup_radio(uhd::i2c_iface::sptr zpu_i2c, x300_clock_
     _db_manager->initialize_dboards();
 
     //now that dboard is created -- register into rx antenna event
-    if (not _rx_fe_map.empty()
-        and _tree->exists(db_path / "rx_frontends" / _rx_fe_map[0].db_fe_name / "antenna" / "value")) {
-        _tree->access<std::string>(db_path / "rx_frontends" / _rx_fe_map[0].db_fe_name / "antenna" / "value")
-            .add_coerced_subscriber(boost::bind(&x300_radio_ctrl_impl::_update_atr_leds, this, _1));
+    if (not _rx_fe_map.empty()) {
+        for (size_t i = 0; i < _get_num_radios(); i++) {
+            if (_tree->exists(db_path / "rx_frontends" / _rx_fe_map[i].db_fe_name / "antenna" / "value")) {
+                // We need a desired subscriber for antenna/value because the experts don't coerce that property.
+                _tree->access<std::string>(db_path / "rx_frontends" / _rx_fe_map[i].db_fe_name / "antenna" / "value")
+                    .add_desired_subscriber(boost::bind(&x300_radio_ctrl_impl::_update_atr_leds, this, _1, i));
+            }
+            _update_atr_leds("", i); //init anyway, even if never called
+        }
     }
-    _update_atr_leds(""); //init anyway, even if never called
 
     //bind frontend corrections to the dboard freq props
     const fs_path db_tx_fe_path = db_path / "tx_frontends";
-    BOOST_FOREACH(const std::string &name, _tree->list(db_tx_fe_path)) {
-        _tree->access<double>(db_tx_fe_path / name / "freq" / "value")
-            .add_coerced_subscriber(boost::bind(&x300_radio_ctrl_impl::set_tx_fe_corrections, this, db_path, _root_path / "tx_fe_corrections" / name, _1));
+    if (not _tx_fe_map.empty()) {
+        for (size_t i = 0; i < _get_num_radios(); i++) {
+            if (_tree->exists(db_tx_fe_path / _tx_fe_map[i].db_fe_name / "freq" / "value")) {
+                _tree->access<double>(db_tx_fe_path / _tx_fe_map[i].db_fe_name / "freq" / "value")
+                        .add_coerced_subscriber(boost::bind(&x300_radio_ctrl_impl::set_tx_fe_corrections, this, db_path,
+                                                            _root_path / "tx_fe_corrections" / _tx_fe_map[i].db_fe_name, _1));
+            }
+        }
     }
     const fs_path db_rx_fe_path = db_path / "rx_frontends";
-    BOOST_FOREACH(const std::string &name, _tree->list(db_rx_fe_path)) {
-        _tree->access<double>(db_rx_fe_path / name / "freq" / "value")
-            .add_coerced_subscriber(boost::bind(&x300_radio_ctrl_impl::set_rx_fe_corrections, this, db_path, _root_path / "rx_fe_corrections" / name,_1));
+    if (not _rx_fe_map.empty()) {
+        for (size_t i = 0; i < _get_num_radios(); i++) {
+            if (_tree->exists(db_rx_fe_path / _tx_fe_map[i].db_fe_name / "freq" / "value")) {
+                _tree->access<double>(db_rx_fe_path / _tx_fe_map[i].db_fe_name / "freq" / "value")
+                        .add_coerced_subscriber(boost::bind(&x300_radio_ctrl_impl::set_rx_fe_corrections, this, db_path,
+                                                            _root_path / "rx_fe_corrections" / _tx_fe_map[i].db_fe_name,
+                                                            _1));
+            }
+        }
     }
 
     ////////////////////////////////////////////////////////////////
@@ -729,16 +766,18 @@ double x300_radio_ctrl_impl::self_cal_adc_xfer_delay(
 /****************************************************************************
  * Helpers
  ***************************************************************************/
-void x300_radio_ctrl_impl::_update_atr_leds(const std::string &rx_ant)
+void x300_radio_ctrl_impl::_update_atr_leds(const std::string &rx_ant, const size_t chan)
 {
-    const bool is_txrx = (rx_ant == "TX/RX");
-    const int rx_led = (1 << 2);
-    const int tx_led = (1 << 1);
-    const int txrx_led = (1 << 0);
-    _leds->set_atr_reg(gpio_atr::ATR_REG_IDLE, 0);
-    _leds->set_atr_reg(gpio_atr::ATR_REG_RX_ONLY, is_txrx? txrx_led : rx_led);
-    _leds->set_atr_reg(gpio_atr::ATR_REG_TX_ONLY, tx_led);
-    _leds->set_atr_reg(gpio_atr::ATR_REG_FULL_DUPLEX, rx_led | tx_led);
+    // The "RX1" port is used by TwinRX and the "TX/RX" port is used by all
+    // other full-duplex dboards. We need to handle both here.
+    const bool is_txrx = (rx_ant == "TX/RX" or rx_ant == "RX1");
+    const int TXRX_RX = (1 << 0);
+    const int TXRX_TX = (1 << 1);
+    const int RX2_RX  = (1 << 2);
+    _leds.at(chan)->set_atr_reg(gpio_atr::ATR_REG_IDLE, 0);
+    _leds.at(chan)->set_atr_reg(gpio_atr::ATR_REG_RX_ONLY, is_txrx ? TXRX_RX : RX2_RX);
+    _leds.at(chan)->set_atr_reg(gpio_atr::ATR_REG_TX_ONLY, TXRX_TX);
+    _leds.at(chan)->set_atr_reg(gpio_atr::ATR_REG_FULL_DUPLEX, RX2_RX | TXRX_TX);
 }
 
 void x300_radio_ctrl_impl::_self_cal_adc_capture_delay(bool print_status)
@@ -855,6 +894,12 @@ void x300_radio_ctrl_impl::_check_adc(const boost::uint32_t val)
     }
 }
 
+void x300_radio_ctrl_impl::_set_db_eeprom(i2c_iface::sptr i2c, const size_t addr, const uhd::usrp::dboard_eeprom_t &db_eeprom)
+{
+    db_eeprom.store(*i2c, addr);
+    _db_eeproms[addr] = db_eeprom;
+}
+
 /****************************************************************************
  * Helpers
  ***************************************************************************/
